from link2media.audio_download import download_audio
from link2media.count_core import cpu_threads
from link2media.quality_audio import high_quality_audio
from link2media.video_download import download_videos